isBreaking property
bool
get
isBreaking
Whether a message composed against the old catalog can still be wrong.
Implementation
bool get isBreaking => kind.breaking;
Whether a message composed against the old catalog can still be wrong.
bool get isBreaking => kind.breaking;