breaking property
Whether a message composed against the old catalog can still be wrong after this change.
Implementation
final bool breaking;
Whether a message composed against the old catalog can still be wrong after this change.
final bool breaking;