encode method
This trace as indented JSON, for a file that is read in review.
Implementation
String encode() => const JsonEncoder.withIndent(' ').convert(toJson());
This trace as indented JSON, for a file that is read in review.
String encode() => const JsonEncoder.withIndent(' ').convert(toJson());