GenUiTraceStep class sealed

One thing that happened during a recorded session.

Implementers

Constructors

GenUiTraceStep.fromJson(Map<String, Object?> json)
Reads back a step written by toJson.
factory

Properties

at → Duration
How long after the start of the recording this happened.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
This step as JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited