GenUiCatalogChange class
One difference between two catalogs.
Constructors
- GenUiCatalogChange(GenUiCatalogChangeKind kind, {required String where, String? detail})
-
Creates a GenUiCatalogChange.
const
Properties
- detail → String?
-
What changed, when saying so needs more than the kind.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBreaking → bool
-
Whether a message composed against the old catalog can still be wrong.
no setter
- kind → GenUiCatalogChangeKind
-
What kind of change it is.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- where → String
-
Where it is:
ProductCard,ProductCard.price, or the catalog itself.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited