GenUiMessageStep class final
A message the agent sent, exactly as it arrived.
- Inheritance
-
- Object
- GenUiTraceStep
- GenUiMessageStep
Constructors
- GenUiMessageStep(Duration at, JsonMap message)
-
Creates a GenUiMessageStep.
const
Properties
- at → Duration
-
How long after the start of the recording this happened.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
message
→ Map<
String, Object?> -
The raw message, in the shape
a2ui_corereads and writes.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
) → A2uiMessage - The message, parsed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
This step as JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited